===============
django Organice
===============

All-in-one collaboration solution.  For non-profit organizations, sports clubs, small to medium-sized businesses.
Nice, very nice, http://organice.io

django Organice is a nice way to run a collaboration platform, an intranet, and websites for your business.
It's a compilation of the best Django packages, preconfigured for getting you started quickly.  Being powered by
the well-known `Django Web framework`_ it's a safe choice for your IT investment providing an easily extensible
architecture.

See http://organice.io for more information.

Fundamental Features
====================

- Enables everyone to contribute to your content---while retaining your full control.
- Continually involves, helps and optimally supports your collaborators by sending out reminders, editing and
  submission hints to avoid losing traction or interest.
- Supports all four common collaboration and support patterns in several ways:

  #. *Active contribution* (create content, contribute corrections)
  #. *Passive contribution* (report issues, assign tasks, provide feedback)
  #. *Active consumption* (search and browse for content)
  #. *Passive consumption* (subscribe to notifications)

Core Components
===============

Major components of django Organice are:

- Django Web framework
- full-featured content management (django CMS)
- full-featured versatile blog (Zinnia, cmsplugin)
- events with event calendar (via Zinnia)
- flexible contact pages (cmsplugin)
- link collection pages
- full-featured newsletter (Emencia)
- todo/issue lists
- social login and user profiles (allauth)
- generic analytics support (analytical)
- multi-language support
- multiple websites support
- database support for PostgreSQL, MySQL, Oracle, and more

Roadmap
=======

We are thrilled to get these awesome features out to you:

- group spaces with automatic mailing list (groupname@example.com)
- documentation area / wiki (probably by use of CMS functionality)
- discussion forum / Q&A board (Askbot, Misago)
- content download for magazine generation
- unobtrusive, integrated, transparent document and asset management
- DropBox, ownCloud, Windows OneDrive, Google Drive, Apple iCloud, etc. integration
- fully integrated search (Haystack)
- web analytics respecting your privacy (Piwik)
- live chat or chat integration

Who is using django Organice?
=============================

Examples of websites running django Organice:

- `Kreuzlingen Rudolf Steiner school`_

Download and Contributions
==========================

Official repositories: (kept in sync)

#. Bitbucket: https://bitbucket.org/bittner/django-organice
#. GitHub: https://github.com/bittner/django-organice

Getting Help
============

- Documentation is available at http://docs.organice.io
- Questions? Please use StackOverflow_.  Tag your questions with ``django-organice``.
- Found a bug? Please use either the Bitbucket_ or GitHub_ issue tracker (you choose)


.. _`Django Web framework`: https://www.djangoproject.com/
.. _`Kreuzlingen Rudolf Steiner school`: http://www.rssk.ch/
.. _StackOverflow: http://stackoverflow.com/questions/tagged/django-organice
.. _Bitbucket: https://bitbucket.org/bittner/django-organice/issues
.. _GitHub: https://github.com/bittner/django-organice/issues
